package cache

import (
	"fmt"
	"hongze/hongze_api/models"
	"hongze/hongze_api/services/go_redis"
	"hongze/hongze_api/utils"
)

// UserViewRedisData 阅读数据
type UserViewRedisData struct {
	Mobile          string `json:"mobile"`
	Email           string `json:"email"`
	RealName        string `json:"real_name"`
	CompanyName     string `json:"company_name"`
	ViewTime        string `json:"view_time" description:"阅读时间，格式：2022-02-17 13:06:13"`
	ProductId       int    `json:"product_id" description:"报告所属产品，ficc：1，权益：2"`
	CompanyId       int    `json:"company_id" description:"客户id"`
	UserId          int    `json:"user_id" description:"用户id"`
	ReportId        int    `json:"report_id" description:"报告ID"`
	ReportChapterId int    `json:"report_chapter_id" description:"章节ID"`
	Source          int8   `json:"source" description:"来源，1：rddp的报告；2：weekly_report的PHP报告；3：weekly_report商品的报告（应该是作废了）；4：察研观向的报告'"`
	StopTime        int    `json:"stop_time" description:"停留时间"`
	OutId           int    `json:"out_id" description:"章节ID"`
}

// PushViewRecordNewRedisData 阅读数据加入到redis
func PushViewRecordNewRedisData(reportViewRecord *models.ReportViewRecord, companyId int) bool {
	data := &UserViewRedisData{
		Mobile:      reportViewRecord.Mobile,
		Email:       reportViewRecord.Email,
		RealName:    reportViewRecord.RealName,
		CompanyName: reportViewRecord.CompanyName,
		ViewTime:    reportViewRecord.CreateTime.Format(utils.FormatDateTime),
		ProductId:   1,
		CompanyId:   companyId,
		UserId:      reportViewRecord.UserId,
		ReportId:    reportViewRecord.ReportId,
		OutId:       reportViewRecord.Id,
	}
	err := go_redis.LPush(utils.CACHE_KEY_USER_VIEW, data)
	if err != nil {
		fmt.Println("PushViewRecordNewRedisData LPush Err:" + err.Error())
	}
	return true
}
